@@ -1,4 +1,5 @@
 from .api import auto_request,SentenceClassification,AutoReWrite,dff_text,get_markdown_images,get_markdown_images_format
 from .diff import dff_text
 # from rewriter import *
-from .cut import auto_cut_markdown
+from .cut import auto_cut_markdown,auto_cut_paragraph,back2text
+from .plus import auto_optimize_content
